@@ -137,6 +137,18 @@ class Boat(object):
         request = self.boatd.post({'value': float(angle)}, '/rudder')
         return request.get('result')
 
+    @property
+    @_auto_update
+    def target_rudder_angle(self):
+        '''
+        Return the current target rudder angle in degrees.
+
+        :returns: rudder angle
+        :rtype: float
+        '''
+        content = self._cached_boat
+        return float(content.get('rudder_angle'))
+
     def set_sail(self, angle):
         '''
         Set the angle of the sail to `angle` degrees
@@ -148,6 +160,18 @@ class Boat(object):
         request = self.boatd.post({'value': float(angle)}, '/sail')
         return request.get('result')
 
+    @property
+    @_auto_update
+    def target_sail_angle(self):
+        '''
+        Return the current target sail angle in degrees.
+
+        :returns: sail angle
+        :rtype: float
+        '''
+        content = self._cached_boat
+        return float(content.get('sail_angle'))
+
 
 class Behaviour(object):
     def __init__(self, boatd=None):
